#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_FINITE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_FINITE_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/scalar/is_finite.hpp>

#endif
